A "language model" is considered to be a folder with the files: `words`, 
`female_names`, `male_names`.

TODO: ATM, there are specific hacks just for English, so we would need some
more work to clean those up before adding a different language model
